@@ -11,10 +11,11 @@ from faker.providers.person.en import Provider
 import numpy as np
 import pandas as pd
 import time
+import re
 
 GB = 1024. * 1024. * 1024.
 MB = 1024. * 1024.
-
+_object_id = "CRED_OBJECT_ID"
 
 def pytest_addoption(parser):
     """
@@ -76,17 +77,21 @@ def pytest_configure(config):
 @pytest.fixture(scope="session")
 def env(env_file):
     load_dotenv(env_file)
-    return environ
+    prefix = "CRED_"
+    my_pattern = re.compile(r'{prefix}\w+'.format(prefix=prefix))
+    my_env_variables = {key.replace(prefix, ''): val for key, val in os.environ.items() if my_pattern.match(key)}
+
+    return my_env_variables
 
 
 @pytest.fixture(scope="session")
 def good_object_id(env):
-    return env["OBJECT_ID"]
+    return env[_object_id]
 
 
 @pytest.fixture(scope="session")
 def object_id_delimiter(env):
-    return env["OBJECT_ID_DELIMITER"]
+    return env[_object_id + "_DELIMITER"]
 
 
 @pytest.fixture(scope="session")
@@ -99,7 +104,7 @@ def separate_good_object_id(good_object_id, object_id_delimiter):
 
 @pytest.fixture(scope="session")
 def bad_object_id(env):
-    return env["OBJECT_ID"] + "_bad"
+    return env[_object_id] + "_bad"
 
 
 @pytest.fixture(scope="session")
